/*
** Copyright 1998 - 2003 Double Precision, Inc.
** See COPYING for distribution information.
*/

/*
** $Id: cginocache.c,v 1.6 2004/10/21 01:12:57 mrsam Exp $
*/
#include	<stdio.h>

void cginocache()
{
	printf("Cache-Control: no-store\n");
	printf("Pragma: no-cache\n");
}

/* MSIE sucks */

void cginocache_msie()
{
	printf("Cache-Control: private\n");
	printf("Pragma: private\n");
}
